[![Stars](https://img.shields.io/github/stars/edbiomedai/scmorph?style=flat&logo=GitHub&color=yellow)](https://github.com/edbiomedai/scmorph/stargazers)
[![PyPI](https://img.shields.io/pypi/v/scmorph?logo=PyPI)](https://pypi.org/project/scmorph)
[![Downloads](https://static.pepy.tech/badge/scmorph)](https://pepy.tech/project/scmorph)
[![Conda](https://img.shields.io/conda/dn/conda-forge/scmorph?logo=Anaconda)](https://anaconda.org/conda-forge/scmorph)
[![Docs](https://readthedocs.org/projects/scmorph/badge/?version=latest)](https://scmorph.readthedocs.io)
[![Chat](https://img.shields.io/badge/zulip-join_chat-%2367b08f.svg)](https://scverse.zulipchat.com)

# scmorph - Single-cell morphological analysis

scmorph is a **Python library** to process **CellPainting** or any
morphological data. It unlocks single-cell data to model heterogenity.

scmorph differs from the popular
[PyCytominer](https://github.com/cytomining/pycytominer) package in the
following ways:

-   **Single-cell**: Enables efficient analysis of single-cell data
-   **Batch-correction**: Natively integrates a [batch correction
    technique](https://doi.org/10.1016/j.cels.2019.03.010) widely used
    for scRNA-seq.
-   **Enhanced feature selection**: Removes non-linearly correlated
    features using an adapted [Chatterjee correlation
    coefficient](https://doi.org/10.48550/arXiv.2108.06828), which
    results in fewer, more meaningful features.
-   **Enhanced aggregation**: Offers statistically robust aggregation
    methods to derive meaningful distances to a control sample.

It provides tools to make single-cell data analysis easier and more
reproducible. For example, it can be used to:

-   Load in data from csv files, e.g. generated by CellProfiler.
-   Remove batch effects to compare conditions across batches.
-   QC both cells and images.
-   Remove redundant features based on correlation.
-   Reduce dimensionality to gain quick intuition about the data\'s
    spread.
-   Perform statistically robust aggregate analysis to quickly identify
    hits.

# Installation

Install scmorph via pip or conda:

```bash
pip install scmorph
# or:
conda install -c conda-forge scmorph
```

# Usage

For documentation on the usage of scmorph, please see
<https://scmorph.readthedocs.io/en/latest/>
